==> zio-aws-mediatailor_3-5.17.103.1-sources.jar: zio/aws/mediatailor/model/DescribeChannelRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DescribeChannelRequest(channelName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.DescribeChannelRequest = {
    import DescribeChannelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.DescribeChannelRequest
      .builder()
      .channelName(__string.unwrap(channelName): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.DescribeChannelRequest.ReadOnly =
    zio.aws.mediatailor.model.DescribeChannelRequest.wrap(buildAwsValue())
}
object DescribeChannelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.DescribeChannelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.DescribeChannelRequest =
      zio.aws.mediatailor.model.DescribeChannelRequest(channelName)
    def channelName: __string
    def getChannelName: ZIO[Any, Nothing, __string] = ZIO.succeed(channelName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.DescribeChannelRequest
  ) extends zio.aws.mediatailor.model.DescribeChannelRequest.ReadOnly {
    override val channelName: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.channelName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.DescribeChannelRequest
  ): zio.aws.mediatailor.model.DescribeChannelRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-mediatailor_3-5.17.163.1-sources.jar: zio/aws/mediatailor/model/DescribeChannelRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DescribeChannelRequest(channelName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.DescribeChannelRequest = {
    import DescribeChannelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.DescribeChannelRequest
      .builder()
      .channelName(channelName: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.DescribeChannelRequest.ReadOnly =
    zio.aws.mediatailor.model.DescribeChannelRequest.wrap(buildAwsValue())
}
object DescribeChannelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.DescribeChannelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.DescribeChannelRequest =
      zio.aws.mediatailor.model.DescribeChannelRequest(channelName)
    def channelName: __string
    def getChannelName: ZIO[Any, Nothing, __string] = ZIO.succeed(channelName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.DescribeChannelRequest
  ) extends zio.aws.mediatailor.model.DescribeChannelRequest.ReadOnly {
    override val channelName: __string = impl.channelName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.DescribeChannelRequest
  ): zio.aws.mediatailor.model.DescribeChannelRequest.ReadOnly = new Wrapper(
    impl
  )
}
